==> senior_design_system-0.21.4.tar.gz: example/lib/pages/card.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class CardExample extends StatefulWidget {
  const CardExample({Key? key}) : super(key: key);

  @override
  _CardExampleState createState() => _CardExampleState();
}

class _CardExampleState extends State<CardExample> {
  bool isChecked = false;

  //
  Widget _buildProfilePicture() {
    return SeniorProfilePicture(
      name: 'Mark Zuckerberg',
      radius: 24.0,
      imageProvider: NetworkImage(
        'https://tecnoblog.net/wp-content/uploads/2019/12/facebook-mark-zuckerberg-f8-2018-1.jpg',
      ),
    );
  }

  Widget _buildMinSizeCard() {
    return SeniorCard(
      onTap: () {},
      rightIcon: FontAwesomeIcons.rocket,
      rightIconColor: SeniorColors.neutralColor800,
      checkboxConfig: CardCheckboxConfig(position: CardCheckboxPosition.right, value: true, onChange: (v) {}),
      withElevation: true,
      child: Center(
        child: Column(
          children: [
            Text(
              'Senior Sistemas',
              style: SeniorTypography.title(color: SeniorColors.neutralColor800),
            ),
          ],
        ),
      ),
    );
  }

  Widget _buildHighlightBorderCard() {
    return SeniorCard(
      onTap: () {
        ScaffoldMessenger.of(context).showSnackBar(
          SeniorSnackBar.message(
            message: 'You just tapped a card with highlight border',
          ),
        );
      },
      onLongPress: () {
        ScaffoldMessenger.of(context).showSnackBar(
          SeniorSnackBar.message(
            message: 'You just long pressed a card with highlight border',
          ),
        );
      },
      withElevation: true,
      highLightBorder: CardHighLightBorder(
        color: SeniorColors.manchesterColorGreen500,
        position: CardBorderPosition.left,
      ),
      rightIcon: FontAwesomeIcons.arrowUp,
      rightIconColor: SeniorColors.primaryColor500,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            'Valor cotas associados',
            style: SeniorTypography.tiny(
              color: SeniorColors.secondaryColor900,
            ),
          ),
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Padding(
                padding: const EdgeInsets.symmetric(
                  vertical: SeniorSpacing.small,
                ),
                child: Row(
                  children: [
                    Text(
                      'R\$',
                      style: SeniorTypography.tiny(
                        color: SeniorColors.neutralColor600,
                      ),
                    ),
                    Text(
                      '30,00',
                      style: SeniorTypography.body(
                        color: SeniorColors.secondaryColor900,
                      ),
                    ),
                  ],
                ),
              ),
              Text(
                '+ 3,49%',
                style: SeniorTypography.body(
                  color: SeniorColors.secondaryColor900,
                ),
              ),
            ],
          ),
          Row(
            children: [
              Text(
                'Saldo atual:',
                style: SeniorTypography.small(
                  color: SeniorColors.neutralColor600,
                ),
              ),
              Text(
                'R\$ 1.385,60',
                style: SeniorTypography.tiny(
                  color: SeniorColors.secondaryColor900,
                ),
              ),
            ],
          )
        ],
      ),
    );
  }

  Widget _buildNormalCard() {
    return SeniorCard(
      onTap: () {
        ScaffoldMessenger.of(context).showSnackBar(
          SeniorSnackBar.message(
            message: 'You just tapped the card',
          ),
        );
      },
      withElevation: true,
      rightIcon: FontAwesomeIcons.chevronRight,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Row(
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              _buildProfilePicture(),
              Padding(
                padding: const EdgeInsets.symmetric(
                  horizontal: SeniorSpacing.xsmall,
                ),
                child: Column(
                  children: [
                    Text('Mark Zuckerberg'),
                    SeniorRating(
                      initialRating: 5,
                      itemCount: 5,
                      onRatingUpdate: (_) {},
                      ignoreGestures: true,
                    ),
                  ],
                ),
              ),
            ],
          ),
          Container(
            padding: const EdgeInsets.symmetric(
              vertical: SeniorSpacing.xxsmall,
            ),
            child: Text(
              'Fernanda. Sua atuação, sua vi...',
              style: SeniorTypography.small(
                color: SeniorColors.neutralColor600,
              ),
            ),
          ),
        ],
      ),
    );
  }

  Widget _buildSmallCard() {
    return SeniorCard(
      height: 160.0,
      width: 140.0,
      onTap: () {
        ScaffoldMessenger.of(context).showSnackBar(
          SeniorSnackBar.message(
            message: 'You just tapped the small card',
          ),
        );
      },
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          _buildProfilePicture(),
          Padding(
            padding: const EdgeInsets.only(
              top: SeniorSpacing.xsmall,
              bottom: SeniorSpacing.small,
            ),
            child: Text(
              'Mark Zuckerberg',
              textAlign: TextAlign.center,
              style: SeniorTypography.smallBold(
                color: SeniorColors.neutralColor800,
              ),
            ),
          ),
          Text(
            'Aniversário:\n14 / mai',
            textAlign: TextAlign.center,
            style: SeniorTypography.small(
              color: SeniorColors.neutralColor800,
            ),
          ),
        ],
      ),
      withElevation: true,
    );
  }

  Widget _buildDismissibleCard() {
    final onChange = (value) {
      print('CLICOU');
      setState(() {
        isChecked = value;
      });
    };

    return SeniorCard(
      onTap: () {
        ScaffoldMessenger.of(context).showSnackBar(
          SeniorSnackBar.message(
            message: 'You just tapped a card with dismissible action',
          ),
        );
      },
      withElevation: true,
      dismissibleConfig: CardDismissibleConfig(
        key: Key('dism'),
        primaryAction: CardDismissibleAction(
          backgroundColor: SeniorColors.primaryColor500,
          icon: FontAwesomeIcons.check,
          onDismissed: () {},
        ),
        secondaryAction: CardDismissibleAction(
          backgroundColor: SeniorColors.manchesterColorRed500,
          icon: FontAwesomeIcons.trash,
          onDismissed: () {},
        ),
      ),
      checkboxConfig: CardCheckboxConfig(
        position: CardCheckboxPosition.right,
        value: isChecked,
        onChange: onChange,
      ),
      rightIcon: FontAwesomeIcons.chevronRight,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            'Campanha de venda de insumos',
            style: SeniorTypography.titleCardBold(
              color: SeniorColors.neutralColor800,
            ),
          ),
          Padding(
            padding: const EdgeInsets.symmetric(
              vertical: SeniorSpacing.small,
            ),
            child: Text(
              'Garanta o valor 2021 para próxima safra',
              style: SeniorTypography.small(
                color: SeniorColors.neutralColor600,
              ),
            ),
          ),
          Row(
            children: [
              SeniorBadge(
                backgroundColor: SeniorColors.manchesterColorGreen,
                fontColor: SeniorColors.pureWhite,
                label: 'Notícias',
              ),
              SizedBox(
                width: SeniorSpacing.medium,
              ),
              Text(
                '13/02/2021',
                style: SeniorTypography.tiny(
                  color: SeniorColors.neutralColor600,
                ),
              ),
            ],
          ),
        ],
      ),
    );
  }

  Widget _buildQuoteCard() {
    return SeniorCard(
      onTap: () {
        ScaffoldMessenger.of(context).showSnackBar(
          SeniorSnackBar.message(
            message: 'You just tapped a card with quotes',
          ),
        );
      },
      withQuotes: true,
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Padding(
            padding: const EdgeInsets.only(bottom: SeniorSpacing.normal),
            child: Text(
              'Fala, amigão!',
              style: SeniorTypography.text(color: SeniorColors.neutralColor800),
            ),
          ),
          Text(
            'Como sempre fazendo história não é mesmo? Muito obrigado por me colocar neste projeto, vem sendo uma oportunidade incrível, parabéns pelos resultados do semestre.',
            style: SeniorTypography.text(color: SeniorColors.neutralColor800),
          ),
        ],
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Card',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(
            SeniorSpacing.normal,
          ),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              Panel(
                title: 'Card',
                child: _buildNormalCard(),
              ),
              Panel(
                title: 'Small cards',
                child: Column(
                  children: [
                    SingleChildScrollView(
                      scrollDirection: Axis.horizontal,
                      child: Row(
                        children: [
                          _buildSmallCard(),
                          _buildSmallCard(),
                          _buildSmallCard(),
                        ],
                      ),
                    ),
                  ],
                ),
              ),
              Panel(
                title: 'Minimum size',
                child: _buildMinSizeCard(),
              ),
              Panel(
                title: 'With highlight border',
                child: _buildHighlightBorderCard(),
              ),
              Panel(
                title: 'Dismissible',
                child: _buildDismissibleCard(),
              ),
              Panel(
                title: 'With quotes',
                child: _buildQuoteCard(),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> senior_design_system-0.22.0.tar.gz: example/lib/pages/card.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class CardExample extends StatefulWidget {
  const CardExample({Key? key}) : super(key: key);

  @override
  _CardExampleState createState() => _CardExampleState();
}

class _CardExampleState extends State<CardExample> {
  bool isChecked = false;
  bool isDisabled = false;

  //
  Widget _buildProfilePicture() {
    return SeniorProfilePicture(
      name: 'Mark Zuckerberg',
      radius: 24.0,
      imageProvider: NetworkImage(
        'https://tecnoblog.net/wp-content/uploads/2019/12/facebook-mark-zuckerberg-f8-2018-1.jpg',
      ),
    );
  }

  Widget _buildMinSizeCard(bool disabled) {
    return SeniorCard(
      disabled: disabled,
      onTap: () {},
      rightIcon: FontAwesomeIcons.rocket,
      rightIconColor: SeniorColors.neutralColor800,
      checkboxConfig: CardCheckboxConfig(position: CardCheckboxPosition.right, value: true, onChange: (v) {}),
      withElevation: true,
      child: Center(
        child: Column(
          children: [
            Text(
              'Senior Sistemas',
              style: SeniorTypography.title(color: SeniorColors.neutralColor800),
            ),
          ],
        ),
      ),
    );
  }

  Widget _buildHighlightBorderCard(bool disabled) {
    return SeniorCard(
      disabled: disabled,
      onTap: () {
        ScaffoldMessenger.of(context).showSnackBar(
          SeniorSnackBar.message(
            message: 'You just tapped a card with highlight border',
          ),
        );
      },
      onLongPress: () {
        ScaffoldMessenger.of(context).showSnackBar(
          SeniorSnackBar.message(
            message: 'You just long pressed a card with highlight border',
          ),
        );
      },
      withElevation: true,
      highLightBorder: CardHighLightBorder(
        color: SeniorColors.manchesterColorGreen500,
        position: CardBorderPosition.left,
      ),
      rightIcon: FontAwesomeIcons.arrowUp,
      rightIconColor: SeniorColors.primaryColor500,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            'Valor cotas associados',
            style: SeniorTypography.tiny(
              color: SeniorColors.secondaryColor900,
            ),
          ),
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Padding(
                padding: const EdgeInsets.symmetric(
                  vertical: SeniorSpacing.small,
                ),
                child: Row(
                  children: [
                    Text(
                      'R\$',
                      style: SeniorTypography.tiny(
                        color: SeniorColors.neutralColor600,
                      ),
                    ),
                    Text(
                      '30,00',
                      style: SeniorTypography.body(
                        color: SeniorColors.secondaryColor900,
                      ),
                    ),
                  ],
                ),
              ),
              Text(
                '+ 3,49%',
                style: SeniorTypography.body(
                  color: SeniorColors.secondaryColor900,
                ),
              ),
            ],
          ),
          Row(
            children: [
              Text(
                'Saldo atual:',
                style: SeniorTypography.small(
                  color: SeniorColors.neutralColor600,
                ),
              ),
              Text(
                'R\$ 1.385,60',
                style: SeniorTypography.tiny(
                  color: SeniorColors.secondaryColor900,
                ),
              ),
            ],
          )
        ],
      ),
    );
  }

  Widget _buildNormalCard(bool disabled) {
    return SeniorCard(
      disabled: disabled,
      onTap: () {
        ScaffoldMessenger.of(context).showSnackBar(
          SeniorSnackBar.message(
            message: 'You just tapped the card',
          ),
        );
      },
      withElevation: false,
      rightIcon: FontAwesomeIcons.chevronRight,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Row(
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              _buildProfilePicture(),
              Padding(
                padding: const EdgeInsets.symmetric(
                  horizontal: SeniorSpacing.xsmall,
                ),
                child: Column(
                  children: [
                    Text('Mark Zuckerberg'),
                    SeniorRating(
                      initialRating: 5,
                      itemCount: 5,
                      onRatingUpdate: (_) {},
                      ignoreGestures: true,
                    ),
                  ],
                ),
              ),
            ],
          ),
          Container(
            padding: const EdgeInsets.symmetric(
              vertical: SeniorSpacing.xxsmall,
            ),
            child: Text(
              'Fernanda. Sua atuação, sua vi...',
              style: SeniorTypography.small(
                color: SeniorColors.neutralColor600,
              ),
            ),
          ),
        ],
      ),
    );
  }

  Widget _buildSmallCard(bool disabled) {
    return SeniorCard(
      disabled: disabled,
      height: 160.0,
      width: 140.0,
      onTap: () {
        ScaffoldMessenger.of(context).showSnackBar(
          SeniorSnackBar.message(
            message: 'You just tapped the small card',
          ),
        );
      },
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          _buildProfilePicture(),
          Padding(
            padding: const EdgeInsets.only(
              top: SeniorSpacing.xsmall,
              bottom: SeniorSpacing.small,
            ),
            child: Text(
              'Mark Zuckerberg',
              textAlign: TextAlign.center,
              style: SeniorTypography.smallBold(
                color: SeniorColors.neutralColor800,
              ),
            ),
          ),
          Text(
            'Aniversário:\n14 / mai',
            textAlign: TextAlign.center,
            style: SeniorTypography.small(
              color: SeniorColors.neutralColor800,
            ),
          ),
        ],
      ),
      withElevation: true,
    );
  }

  Widget _buildDismissibleCard(bool disabled) {
    final onChange = (value) {
      print('CLICOU');
      setState(() {
        isChecked = value;
      });
    };

    return SeniorCard(
      disabled: disabled,
      onTap: () {
        ScaffoldMessenger.of(context).showSnackBar(
          SeniorSnackBar.message(
            message: 'You just tapped a card with dismissible action',
          ),
        );
      },
      withElevation: true,
      dismissibleConfig: CardDismissibleConfig(
        key: Key('dism'),
        primaryAction: CardDismissibleAction(
          backgroundColor: SeniorColors.primaryColor500,
          icon: FontAwesomeIcons.check,
          onDismissed: () {},
        ),
        secondaryAction: CardDismissibleAction(
          backgroundColor: SeniorColors.manchesterColorRed500,
          icon: FontAwesomeIcons.trash,
          onDismissed: () {},
        ),
      ),
      checkboxConfig: CardCheckboxConfig(
        position: CardCheckboxPosition.right,
        value: isChecked,
        onChange: onChange,
      ),
      rightIcon: FontAwesomeIcons.chevronRight,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            'Campanha de venda de insumos',
            style: SeniorTypography.titleCardBold(
              color: SeniorColors.neutralColor800,
            ),
          ),
          Padding(
            padding: const EdgeInsets.symmetric(
              vertical: SeniorSpacing.small,
            ),
            child: Text(
              'Garanta o valor 2021 para próxima safra',
              style: SeniorTypography.small(
                color: SeniorColors.neutralColor600,
              ),
            ),
          ),
          Row(
            children: [
              SeniorBadge(
                backgroundColor: SeniorColors.manchesterColorGreen,
                fontColor: SeniorColors.pureWhite,
                label: 'Notícias',
              ),
              SizedBox(
                width: SeniorSpacing.medium,
              ),
              Text(
                '13/02/2021',
                style: SeniorTypography.tiny(
                  color: SeniorColors.neutralColor600,
                ),
              ),
            ],
          ),
        ],
      ),
    );
  }

  Widget _buildQuoteCard(bool disabled) {
    return SeniorCard(
      disabled: disabled,
      onTap: () {
        ScaffoldMessenger.of(context).showSnackBar(
          SeniorSnackBar.message(
            message: 'You just tapped a card with quotes',
          ),
        );
      },
      withQuotes: true,
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Padding(
            padding: const EdgeInsets.only(bottom: SeniorSpacing.normal),
            child: Text(
              'Fala, amigão!',
              style: SeniorTypography.text(color: SeniorColors.neutralColor800),
            ),
          ),
          Text(
            'Como sempre fazendo história não é mesmo? Muito obrigado por me colocar neste projeto, vem sendo uma oportunidade incrível, parabéns pelos resultados do semestre.',
            style: SeniorTypography.text(color: SeniorColors.neutralColor800),
          ),
        ],
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Card',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(
            SeniorSpacing.normal,
          ),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              SeniorSwitch(
                fullLenght: true,
                title: 'Desabilitar cards',
                titlePosition: SeniorSwitchTitlePosition.left,
                onChanged: (disabled) => setState(() {
                  this.isDisabled = disabled ?? false;
                }),
                value: this.isDisabled,
              ),
              Panel(
                title: 'Card',
                child: _buildNormalCard(this.isDisabled),
              ),
              Panel(
                title: 'Small cards',
                child: Column(
                  children: [
                    SingleChildScrollView(
                      scrollDirection: Axis.horizontal,
                      child: Row(
                        children: [
                          _buildSmallCard(this.isDisabled),
                          _buildSmallCard(this.isDisabled),
                          _buildSmallCard(this.isDisabled),
                        ],
                      ),
                    ),
                  ],
                ),
              ),
              Panel(
                title: 'Minimum size',
                child: _buildMinSizeCard(this.isDisabled),
              ),
              Panel(
                title: 'With highlight border',
                child: _buildHighlightBorderCard(this.isDisabled),
              ),
              Panel(
                title: 'Dismissible',
                child: _buildDismissibleCard(this.isDisabled),
              ),
              Panel(
                title: 'With quotes',
                child: _buildQuoteCard(this.isDisabled),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
